from spryx_core import NOT_GIVEN, is_given
from spryx_http import SpryxAsyncClient

from spryx_agents.types.vector_store import VectorFileStatus


class VectorStores:
    def __init__(self, client: SpryxAsyncClient):
        self._client = client

    async def list_vector_stores(
        self,
        page: int = 1,
        limit: int = 10,
        order: str = "asc",
    ) -> dict:
        """List all vector stores."""
        return await self._client.get(
            "/vector-stores",
            params={"page": page, "limit": limit, "order": order},
        )

    async def create_vector_store(
        self,
        name: str,
        description: str,
    ) -> dict:
        """Create a new vector store."""
        payload = {
            "name": name,
            "description": description,
        }

        return await self._client.post("/vector-stores", json=payload)

    async def get_vector_store(
        self,
        vector_store_id: str,
    ) -> dict:
        """Retrieve a specific vector store by ID."""
        return await self._client.get(f"/vector-stores/{vector_store_id}")

    async def add_file_to_vector_store(
        self,
        vector_store_id: str,
        file_id: str,
    ) -> dict:
        """Add a file to a vector store."""
        payload = {
            "file_id": file_id,
        }

        return await self._client.post(
            f"/vector-stores/{vector_store_id}/files",
            json=payload,
        )

    async def update_vector_file(
        self,
        vector_store_id: str,
        file_id: str,
        status: VectorFileStatus,
        organization_id: str,
        failed_reason: str = NOT_GIVEN,
        tokens_size: int = NOT_GIVEN,
    ) -> dict:
        """Update a vector file status."""
        payload = {"status": status.value}

        if is_given(failed_reason):
            payload["failed_reason"] = failed_reason

        if is_given(tokens_size):
            payload["tokens_size"] = tokens_size

        return await self._client.put(
            f"/vector-stores/{vector_store_id}/files/{file_id}",
            json=payload,
            headers={"x-organization-id": organization_id},
        )



from spryx_core import NOT_GIVEN, is_given
from spryx_http import SpryxAsyncClient


class Credentials:
    def __init__(self, client: SpryxAsyncClient):
        self._client = client

    async def list_credentials(
        self,
        page: int = 1,
        limit: int = 10,
        order: str = "asc",
        type: str = NOT_GIVEN,
    ) -> dict:
        """List all credentials."""
        params = {"page": page, "limit": limit, "order": order}
        
        if is_given(type):
            params["type"] = type
            
        return await self._client.get(
            "/v1/credentials/",
            params=params,
        )

    async def create_credential(
        self,
        title: str,
        type: str,
        values: dict,
    ) -> dict:
        """Create a new credential."""
        payload = {
            "title": title,
            "type": type,
            "values": values,
        }

        return await self._client.post("/v1/credentials/", json=payload)

    async def get_credential(
        self,
        credential_id: str,
    ) -> dict:
        """Retrieve a credential by ID."""
        return await self._client.get(f"/v1/credentials/{credential_id}")

    async def update_credential(
        self,
        credential_id: str,
        title: str = NOT_GIVEN,
        values: dict = NOT_GIVEN,
    ) -> dict:
        """Update an existing credential."""
        payload = {}
        
        if is_given(title):
            payload["title"] = title
            
        if is_given(values):
            payload["values"] = values

        return await self._client.put(
            f"/v1/credentials/{credential_id}",
            json=payload,
        )

    async def delete_credential(
        self,
        credential_id: str,
    ) -> dict:
        """Delete a credential."""
        return await self._client.delete(f"/v1/credentials/{credential_id}") 


from spryx_agents.resources.agents import Agents
from spryx_agents.resources.chats import Chats
from spryx_agents.resources.credential_types import CredentialTypes
from spryx_agents.resources.credentials import Credentials
from spryx_agents.resources.files import Files
from spryx_agents.resources.integrations import Integrations
from spryx_agents.resources.vector_stores import VectorStores

__all__ = [
    "Agents", 
    "Chats", 
    "CredentialTypes", 
    "Credentials", 
    "Files", 
    "Integrations", 
    "VectorStores"
]



from spryx_http import SpryxAsyncClient


class Integrations:
    def __init__(self, client: SpryxAsyncClient):
        self._client = client

    async def list_integrations(self) -> dict:
        """List all available integrations."""
        return await self._client.get("/v1/integrations/") 


from spryx_http import SpryxAsyncClient


class EmbeddingUsages:
    def __init__(self, client: SpryxAsyncClient):
        self.client = client

    async def add_embedding_usage(
        self,
        organization_id: str,
        vector_store_id: str,
        model: str,
        embedding_tokens: int,
        embedding_requests: int,
    ) -> list[dict]:
        return await self.client.post(
            "/v1/embedding-usages",
            json={
                "kind": "add_text",
                "vector_store_id": vector_store_id,
                "model": model,
                "embedding_tokens": embedding_tokens,
                "embedding_requests": embedding_requests,
            },
            headers={"x-organization-id": organization_id},
        )
